<?php
require_once "open_basedir.inc";
create_directories();

var_dump(file_exists('./test/ok/ok.txt'));
var_dump(file_exists('./test/foo'));

$file = str_repeat('x', 2 * PHP_MAXPATHLEN);
var_dump(file_exists("./test/$file"));
?>
<?php error_reporting(0); ?>
<?php
require_once "open_basedir.inc";
delete_directories();
?>